Release History
===============

0.1.6
-----

* Major speed improvements in generated code
* Improvements to generator handling
* Improvements to exception handling
* Added support for `yield from`

0.1.5
-----

* Added support for if conditions in list comprehensions
* Added support for printf-style formatting
* Several fixes for arguments handling and operations with numbers
* Many bugfixes and improvements to docs, tests and error messages
* Added implementations for many builtin functions and type methods
* VOC jar library now ships with the stdlib modules that it already compiles


0.1.4
-----

* Added support for self-assignment for attributes and subscript
* Added support for multiple comparison
* Improved support for slices
* Many bugfixes and improvements to docs and tests
* Added implementations for many builtin functions and type methods
* VOC is now tested in Python 3.6, and uses BeeKeeper for CI

0.1.3
-----

Progress release. VOC is able to run Toga tutorials on Android.

0.1.2
-----

Progress release. VOC is able to compile the Toga and Colosseum libraries.

0.1.1
-----

Switched approach to parse Python code with ``ast`` instead of transpiling
CPython bytecode.

Many bugs fixed.

0.1.0
-----

Progress release. VOC is currently able to compile a simple working Android
application.

0.0.1
-----

Initial public release.
